@@ -3,18 +3,24 @@ package SQL::Tokenizer;
 use warnings;
 use strict;
 
-use 5.006.002;
+use 5.006002;
 
-our $VERSION= '0.16';
+use Exporter;
+
+our @ISA = qw(Exporter);
+
+our @EXPORT_OK= qw(tokenize_sql);
+
+our $VERSION= '0.18';
 
 my $re= qr{
     (
         (?:--|\#)[\ \t\S]*      # single line comments
         |
-        (?:<>|<=>|>=|<=|==|=|!=|!|<<|>>|<|>|\|\||\||&&|&|-|\+|\*(?!/)|/(?!\*)|\%|~|\^|\?)      
+        (?:<>|<=>|>=|<=|==|=|!=|!|<<|>>|<|>|\|\||\||&&|&|-|\+|\*(?!/)|/(?!\*)|\%|~|\^|\?)
                                 # operators and tests
         |
-        [\(\),;]                # punctuation (parenthesis, comma)
+        [\[\]\(\),;]            # punctuation (parenthesis, comma)
         |
         \'\'(?!\')              # empty single quoted string
         |
@@ -34,11 +40,11 @@ my $re= qr{
         \n                      # newline
         |
         [\t\ ]+                 # any kind of white spaces
-    )   
+    )
 }smx;
 
-sub tokenize {
-    my ( $class, $query, $remove_white_tokens )= @_;
+sub tokenize_sql {
+    my ( $query, $remove_white_tokens )= @_;
 
     my @query= $query =~ m{$re}smxg;
 
@@ -49,6 +55,11 @@ sub tokenize {
     return wantarray ? @query : \@query;
 }
 
+sub tokenize {
+    my $class= shift;
+    return tokenize_sql(@_);
+}
+
 1;
 
 =pod
@@ -61,12 +72,14 @@ SQL::Tokenizer - A simple SQL tokenizer.
 
 =head1 SYNOPSIS
 
- use SQL::Tokenizer;
+ use SQL::Tokenizer qw(tokenize_sql);
 
- my $query = q{SELECT 1 + 1};
- my @tokens = SQL::Tokenizer->tokenize($query);
+ my $query= q{SELECT 1 + 1};
+ my @tokens= SQL::Tokenizer->tokenize($query);
 
- # @tokens contains ('SELECT', ' ', '1', ' ', '+', ' ', '1')
+ # @tokens now contains ('SELECT', ' ', '1', ' ', '+', ' ', '1')
+
+ @tokens= tokenize_sql($query); # procedural interface
 
 =head1 DESCRIPTION
 
@@ -90,14 +103,27 @@ like the one below should not be a problem:
 
 =over 4
 
-=item tokenizer
+=item tokenize_sql
 
-    my @tokens= SQL::Tokenizer->tokenize($query);
-    my $tokens= SQL::Tokenizer->tokenize($query);
+ use SQL::Tokenizer qw(tokenize_sql);
 
-    $tokens= SQL::Tokenizer->tokenize( $query, $remove_white_tokens );
+ my @tokens= tokenize_sql($query);
+ my $tokens= tokenize_sql($query);
 
-This is the only available method. It receives a SQL query, and returns an
+ $tokens= tokenize_sql( $query, $remove_white_tokens );
+
+C<tokenize_sql> can be imported to current namespace on request. It receives a
+SQL query, and returns an array of tokens if called in list context, or an 
+arrayref if called in scalar context.
+
+=item tokenize
+
+ my @tokens= SQL::Tokenizer->tokenize($query);
+ my $tokens= SQL::Tokenizer->tokenize($query);
+
+ $tokens= SQL::Tokenizer->tokenize( $query, $remove_white_tokens );
+
+This is the only available class method. It receives a SQL query, and returns an
 array of tokens if called in list context, or an arrayref if called in scalar
 context.
 
@@ -108,9 +134,18 @@ result.
 
 =head1 ACKNOWLEDGEMENTS
 
+=over 4
+
+=item 
+
 Evan Harris, for implementing Shell comment style and SQL operators.
+
+=item
+
 Charlie Hills, for spotting a lot of important issues I haven't thought.
 
+=back
+
 =head1 AUTHOR
 
 Copyright (c) 2007, 2008 Igor Sutton Lopes "<IZUT@cpan.org>". All rights
